@@ -24,8 +24,6 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-fargate-sqs`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.fargatesqs`|
 
-## Overview
-
 This AWS Solutions Construct implements an AWS Fargate service that can write to an Amazon SQS queue
 
 Here is a minimal deployable pattern definition:
@@ -33,53 +31,22 @@ Here is a minimal deployable pattern definition:
 Typescript
 
 ```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
 import { FargateToSqs, FargateToSqsProps } from '@aws-solutions-constructs/aws-fargate-sqs';
 
-const constructProps: FargateToSqsProps = {
+const props: FargateToSqsProps = {
     publicApi: true,
-    ecrRepositoryArn: "arn:aws:ecr:us-east-1:123456789012:repository/your-ecr-repo"
-};
+    ecrRepositoryArn: "arn of a repo in ECR in your account",
+});
 
-new FargateToSqs(this, 'test-construct', constructProps);
-```
-
-Python
-
-```python
-from aws_solutions_constructs.aws_fargate_sqs import FargateToSqs, FargateToSqsProps
-from aws_cdk import (
-    Stack
-)
-from constructs import Construct
-
-FargateToSqs(self, 'test_construct',
-            public_api=True,
-            ecr_repository_arn="arn:aws:ecr:us-east-1:123456789012:repository/your-ecr-repo")
-```
-
-Java
-
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awsconstructs.services.fargatesqs.*;
-
-new FargateToSqs(this, "test_construct", new FargateToSqsProps.Builder()
-        .publicApi(true)
-        .ecrRepositoryArn("arn:aws:ecr:us-east-1:123456789012:repository/your-ecr-repo")
-        .build());
+new FargateToSqs(stack, 'test-construct', props);
 ```
 
 ## Pattern Construct Props
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-| publicApi | boolean | Whether the construct is deploying a private or public API. This has implications for the VPC. |
-| vpcProps? | [ec2.VpcProps](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.VpcProps.html) | Optional custom properties for a VPC the construct will create. This VPC will be used by any Private Hosted Zone the construct creates (that's why loadBalancerProps and privateHostedZoneProps can't include a VPC). Providing both this and existingVpc is an error. |
+| publicApi | boolean | Whether the construct is deploying a private or public API. This has implications for the VPC and ALB. |
+| vpcProps? | [ec2.VpcProps](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.VpcProps.html) | Optional custom properties for a VPC the construct will create. This VPC will be used by the new ALB and any Private Hosted Zone the construct creates (that's why loadBalancerProps and privateHostedZoneProps can't include a VPC). Providing both this and existingVpc is an error. |
 | existingVpc? | [ec2.IVpc](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.IVpc.html) | An existing VPC in which to deploy the construct. Providing both this and vpcProps is an error. If the client provides an existing load balancer and/or existing Private Hosted Zone, those constructs must exist in this VPC. |
 | clusterProps? | [ecs.ClusterProps](https://docs.aws.amazon.com/cdk/api/v1/docs/@aws-cdk_aws-ecs.ClusterProps.html) | Optional properties to create a new ECS cluster. To provide an existing cluster, use the cluster attribute of fargateServiceProps. |
 | ecrRepositoryArn? | string | The arn of an ECR Repository containing the image to use to generate the containers. Either this or the image property of containerDefinitionProps must be provided. format: arn:aws:ecr:*region*:*account number*:repository/*Repository Name* |
@@ -87,15 +54,14 @@ new FargateToSqs(this, "test_construct", new FargateToSqsProps.Builder()
 | containerDefinitionProps? | [ecs.ContainerDefinitionProps | any](https://docs.aws.amazon.com/cdk/api/v1/docs/@aws-cdk_aws-ecs.ContainerDefinitionProps.html) | Optional props to define the container created for the Fargate Service (defaults found in fargate-defaults.ts) |
 | fargateTaskDefinitionProps? | [ecs.FargateTaskDefinitionProps | any](https://docs.aws.amazon.com/cdk/api/v1/docs/@aws-cdk_aws-ecs.FargateTaskDefinitionProps.html) | Optional props to define the Fargate Task Definition for this construct  (defaults found in fargate-defaults.ts) |
 | fargateServiceProps? | [ecs.FargateServiceProps | any](https://docs.aws.amazon.com/cdk/api/v1/docs/@aws-cdk_aws-ecs.FargateServiceProps.html) | Optional values to override default Fargate Task definition properties (fargate-defaults.ts). The construct will default to launching the service is the most isolated subnets available (precedence: Isolated, Private and Public). Override those and other defaults here. |
-| existingFargateServiceObject? | [ecs.FargateService](https://docs.aws.amazon.com/cdk/api/v1/docs/@aws-cdk_aws-ecs.FargateService.html) | A Fargate Service already instantiated (probably by another Solutions Construct). If this is specified, then no props defining a new service can be provided, including: ecrImageVersion, containerDefinitionProps, fargateTaskDefinitionProps, ecrRepositoryArn, fargateServiceProps, clusterProps |
+| existingFargateServiceObject? | [ecs.FargateService](https://docs.aws.amazon.com/cdk/api/v1/docs/@aws-cdk_aws-ecs.FargateService.html) | A Fargate Service already instantiated (probably by another Solutions Construct). If this is specified, then no props defining a new service can be provided, including: existingImageObject, ecrImageVersion, containerDefintionProps, fargateTaskDefinitionProps, ecrRepositoryArn, fargateServiceProps, clusterProps, existingClusterInterface |
 | existingContainerDefinitionObject? | [ecs.ContainerDefinition](https://docs.aws.amazon.com/cdk/api/v1/docs/@aws-cdk_aws-ecs.ContainerDefinition.html) | A container definition already instantiated as part of a Fargate service. This must be the container in the existingFargateServiceObject |
 |existingQueueObj?|[sqs.Queue](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.Queue.html)|An optional, existing SQS queue to be used instead of the default queue. Providing both this and queueProps will cause an error.|
 |queueProps?|[sqs.QueueProps](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.QueueProps.html)|Optional user-provided properties to override the default properties for the SQS queue.|
 |deployDeadLetterQueue?|boolean|Whether to create a secondary queue to be used as a dead letter queue. Defaults to `true`.|
 |deadLetterQueueProps?|[sqs.QueueProps](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.QueueProps.html)|Optional user-provided props to override the default props for the dead letter queue. Only used if the `deployDeadLetterQueue` property is set to true.|
 |maxReceiveCount?|integer|The number of times a message can be unsuccessfully dequeued before being moved to the dead letter queue. Defaults to `15`.|
-|queueUrlEnvironmentVariableName?|string|Optional Name for the container environment variable set to the URL of the queue. Default: SQS_QUEUE_URL |
-|queueArnEnvironmentVariableName?|string|Optional Name for the container environment variable set to the arn of the queue. Default: SQS_QUEUE_ARN |
+|queueUrlEnvironmentVariableName?|string|Optional Name for the SQS queue name environment variable set for the container.|
 |queuePermissions?|`string[]`|Optional queue permissions to grant to the Fargate service. One or more of the following may be specified: `Read`,`Write`. Default is `Write`|
 
 ## Pattern Properties
@@ -149,30 +115,28 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_ec2
 import aws_cdk.aws_ecs
 import aws_cdk.aws_sqs
-import aws_cdk.core
+import constructs
 
 
 class FargateToSqs(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-fargate-sqs.FargateToSqs",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         public_api: builtins.bool,
-        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
+        cluster_props: typing.Optional[aws_cdk.aws_ecs.ClusterProps] = None,
         container_definition_props: typing.Any = None,
-        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
@@ -185,9 +149,9 @@ class FargateToSqs(
         max_receive_count: typing.Optional[jsii.Number] = None,
         queue_arn_environment_variable_name: typing.Optional[builtins.str] = None,
         queue_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
-        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
         queue_url_environment_variable_name: typing.Optional[builtins.str] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
     ) -> None:
         '''
         :param scope: -
@@ -206,41 +170,12 @@ class FargateToSqs(
         :param fargate_service_props: Optional values to override default Fargate Task definition properties (fargate-defaults.ts). The construct will default to launching the service is the most isolated subnets available (precedence: Isolated, Private and Public). Override those and other defaults here. defaults - fargate-defaults.ts
         :param fargate_task_definition_props: -
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue. Default: - required field if deployDeadLetterQueue=true.
-        :param queue_arn_environment_variable_name: Optional Name for the container environment variable set to the arn of the queue. Default: - SQS_QUEUE_ARN
+        :param queue_arn_environment_variable_name: Optional Name for the SQS queue ARN environment variable to set for the container. Default: - None
         :param queue_permissions: Optional queue permissions to grant to the Fargate service. One or more of the following may be specified: ``Read``,``Write``. Default is ``Write`` Default: - Write
         :param queue_props: Optional user-provided props to override the default props for the SQS queue. Default: - Default props are used
-        :param queue_url_environment_variable_name: Optional Name for the container environment variable set to the URL of the queue. Default: - SQS_QUEUE_URL
+        :param queue_url_environment_variable_name: Optional Name for the SQS queue name environment variable to set for the container. Default: - None
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An SQS Interface endpoint will be included in this VPC. Default: - none
         '''
-        if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                public_api: builtins.bool,
-                cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
-                container_definition_props: typing.Any = None,
-                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
-                ecr_image_version: typing.Optional[builtins.str] = None,
-                ecr_repository_arn: typing.Optional[builtins.str] = None,
-                existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-                existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                fargate_service_props: typing.Any = None,
-                fargate_task_definition_props: typing.Any = None,
-                max_receive_count: typing.Optional[jsii.Number] = None,
-                queue_arn_environment_variable_name: typing.Optional[builtins.str] = None,
-                queue_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
-                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                queue_url_environment_variable_name: typing.Optional[builtins.str] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = FargateToSqsProps(
             public_api=public_api,
             cluster_props=cluster_props,
@@ -265,27 +200,27 @@ class FargateToSqs(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="container")
     def container(self) -> aws_cdk.aws_ecs.ContainerDefinition:
         return typing.cast(aws_cdk.aws_ecs.ContainerDefinition, jsii.get(self, "container"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="service")
     def service(self) -> aws_cdk.aws_ecs.FargateService:
         return typing.cast(aws_cdk.aws_ecs.FargateService, jsii.get(self, "service"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="sqsQueue")
     def sqs_queue(self) -> aws_cdk.aws_sqs.Queue:
         return typing.cast(aws_cdk.aws_sqs.Queue, jsii.get(self, "sqsQueue"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> aws_cdk.aws_ec2.IVpc:
         return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.get(self, "vpc"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="deadLetterQueue")
     def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue]:
         return typing.cast(typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue], jsii.get(self, "deadLetterQueue"))
@@ -321,9 +256,9 @@ class FargateToSqsProps:
         self,
         *,
         public_api: builtins.bool,
-        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
+        cluster_props: typing.Optional[aws_cdk.aws_ecs.ClusterProps] = None,
         container_definition_props: typing.Any = None,
-        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
@@ -336,9 +271,9 @@ class FargateToSqsProps:
         max_receive_count: typing.Optional[jsii.Number] = None,
         queue_arn_environment_variable_name: typing.Optional[builtins.str] = None,
         queue_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
-        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
         queue_url_environment_variable_name: typing.Optional[builtins.str] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
     ) -> None:
         '''
         :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct. Default: - none
@@ -355,10 +290,10 @@ class FargateToSqsProps:
         :param fargate_service_props: Optional values to override default Fargate Task definition properties (fargate-defaults.ts). The construct will default to launching the service is the most isolated subnets available (precedence: Isolated, Private and Public). Override those and other defaults here. defaults - fargate-defaults.ts
         :param fargate_task_definition_props: -
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue. Default: - required field if deployDeadLetterQueue=true.
-        :param queue_arn_environment_variable_name: Optional Name for the container environment variable set to the arn of the queue. Default: - SQS_QUEUE_ARN
+        :param queue_arn_environment_variable_name: Optional Name for the SQS queue ARN environment variable to set for the container. Default: - None
         :param queue_permissions: Optional queue permissions to grant to the Fargate service. One or more of the following may be specified: ``Read``,``Write``. Default is ``Write`` Default: - Write
         :param queue_props: Optional user-provided props to override the default props for the SQS queue. Default: - Default props are used
-        :param queue_url_environment_variable_name: Optional Name for the container environment variable set to the URL of the queue. Default: - SQS_QUEUE_URL
+        :param queue_url_environment_variable_name: Optional Name for the SQS queue name environment variable to set for the container. Default: - None
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An SQS Interface endpoint will be included in this VPC. Default: - none
         '''
         if isinstance(cluster_props, dict):
@@ -369,50 +304,6 @@ class FargateToSqsProps:
             queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
-        if __debug__:
-            def stub(
-                *,
-                public_api: builtins.bool,
-                cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
-                container_definition_props: typing.Any = None,
-                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
-                ecr_image_version: typing.Optional[builtins.str] = None,
-                ecr_repository_arn: typing.Optional[builtins.str] = None,
-                existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-                existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                fargate_service_props: typing.Any = None,
-                fargate_task_definition_props: typing.Any = None,
-                max_receive_count: typing.Optional[jsii.Number] = None,
-                queue_arn_environment_variable_name: typing.Optional[builtins.str] = None,
-                queue_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
-                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                queue_url_environment_variable_name: typing.Optional[builtins.str] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
-            check_type(argname="argument cluster_props", value=cluster_props, expected_type=type_hints["cluster_props"])
-            check_type(argname="argument container_definition_props", value=container_definition_props, expected_type=type_hints["container_definition_props"])
-            check_type(argname="argument dead_letter_queue_props", value=dead_letter_queue_props, expected_type=type_hints["dead_letter_queue_props"])
-            check_type(argname="argument deploy_dead_letter_queue", value=deploy_dead_letter_queue, expected_type=type_hints["deploy_dead_letter_queue"])
-            check_type(argname="argument ecr_image_version", value=ecr_image_version, expected_type=type_hints["ecr_image_version"])
-            check_type(argname="argument ecr_repository_arn", value=ecr_repository_arn, expected_type=type_hints["ecr_repository_arn"])
-            check_type(argname="argument existing_container_definition_object", value=existing_container_definition_object, expected_type=type_hints["existing_container_definition_object"])
-            check_type(argname="argument existing_fargate_service_object", value=existing_fargate_service_object, expected_type=type_hints["existing_fargate_service_object"])
-            check_type(argname="argument existing_queue_obj", value=existing_queue_obj, expected_type=type_hints["existing_queue_obj"])
-            check_type(argname="argument existing_vpc", value=existing_vpc, expected_type=type_hints["existing_vpc"])
-            check_type(argname="argument fargate_service_props", value=fargate_service_props, expected_type=type_hints["fargate_service_props"])
-            check_type(argname="argument fargate_task_definition_props", value=fargate_task_definition_props, expected_type=type_hints["fargate_task_definition_props"])
-            check_type(argname="argument max_receive_count", value=max_receive_count, expected_type=type_hints["max_receive_count"])
-            check_type(argname="argument queue_arn_environment_variable_name", value=queue_arn_environment_variable_name, expected_type=type_hints["queue_arn_environment_variable_name"])
-            check_type(argname="argument queue_permissions", value=queue_permissions, expected_type=type_hints["queue_permissions"])
-            check_type(argname="argument queue_props", value=queue_props, expected_type=type_hints["queue_props"])
-            check_type(argname="argument queue_url_environment_variable_name", value=queue_url_environment_variable_name, expected_type=type_hints["queue_url_environment_variable_name"])
-            check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "public_api": public_api,
         }
@@ -586,9 +477,9 @@ class FargateToSqsProps:
 
     @builtins.property
     def queue_arn_environment_variable_name(self) -> typing.Optional[builtins.str]:
-        '''Optional Name for the container environment variable set to the arn of the queue.
+        '''Optional Name for the SQS queue ARN environment variable to set for the container.
 
-        :default: - SQS_QUEUE_ARN
+        :default: - None
         '''
         result = self._values.get("queue_arn_environment_variable_name")
         return typing.cast(typing.Optional[builtins.str], result)
@@ -615,9 +506,9 @@ class FargateToSqsProps:
 
     @builtins.property
     def queue_url_environment_variable_name(self) -> typing.Optional[builtins.str]:
-        '''Optional Name for the container environment variable set to the URL of the queue.
+        '''Optional Name for the SQS queue name environment variable to set for the container.
 
-        :default: - SQS_QUEUE_URL
+        :default: - None
         '''
         result = self._values.get("queue_url_environment_variable_name")
         return typing.cast(typing.Optional[builtins.str], result)
